Page 95 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 95

Home

    Naval Intelligence. Much of the truth about the sinking
    of the Lusitania was revealed by British author, Colin
    Simpson, in his book The Lusitania.

    The deaths of 128 Americans aboard the ill-fated ship

    propelled the United States into the war. This was
    despite the fact that Germany had put advertisements in
    New York newspapers advising Americans not to board
    the ship because it was carrying munitions to England.
    To cover up this fact, President Wilson ordered the cargo
    records listing the munitions sealed up in the national
    archives. Thus, world events were set into motion, by a
    master plan of deception, which were eventually to alter

    the course of history.

    The purpose of getting the United States into World
    War I was to establish world government through the
    League of Nations. When Congress refused to go along
    with this scheme, and rejected membership in the League
    of Nations, it was decided that America would have to

    be changed before it would enter into world government.
    In 1919, at a meeting in Paris led by Colonel Edward

    in England and one in the United States. The American
    branch was vas incorporated i in New York as the Council on

    Foreign Relations on J uly 29, 1921.
    In 1912, a novel was published that had been written

    by Edward Mandel House. This novel, entitled Philip
    Dru: Administrator, called for "Socialism ¢ as dreamed of

    90

    The Secret Side of History

    Mandel House, it was resolved that an “Institute of

    International Affairs" be formed with two branches, one

    by Karl Marx." Unfortunately, House lived to see some